[PATCH 1/2] lib: add __sysfs_match_string_with_gaps() helper

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



This helper is similar to __sysfs_match_string() with the exception that it
ignores NULL elements within the array.
It takes an extra parameter (called `gaps`) which when true will ignore
the NULL elements. When false, this function behaves exactly like
`__sysfs_match_string()`.

Signed-off-by: Alexandru Ardelean <alexandru.ardelean@xxxxxxxxxx>
---
 include/linux/string.h |  9 ++++++++-
 lib/string.c           | 14 ++++++++++----
 2 files changed, 18 insertions(+), 5 deletions(-)

diff --git a/include/linux/string.h b/include/linux/string.h
index 7927b875f80c..30595ed483dc 100644
--- a/include/linux/string.h
+++ b/include/linux/string.h
@@ -189,7 +189,14 @@ static inline int strtobool(const char *s, bool *res)
 }
 
 int match_string(const char * const *array, size_t n, const char *string);
-int __sysfs_match_string(const char * const *array, size_t n, const char *s);
+int __sysfs_match_string_with_gaps(const char * const *array, size_t n,
+				   const char *str, bool gaps);
+
+static inline int __sysfs_match_string(const char * const *array, size_t n,
+				       const char *str)
+{
+	return __sysfs_match_string_with_gaps(array, n, str, false);
+}
 
 /**
  * sysfs_match_string - matches given string in an array
diff --git a/lib/string.c b/lib/string.c
index 38e4ca08e757..8ddac3cd292a 100644
--- a/lib/string.c
+++ b/lib/string.c
@@ -659,30 +659,36 @@ int match_string(const char * const *array, size_t n, const char *string)
 EXPORT_SYMBOL(match_string);
 
 /**
  * __sysfs_match_string - matches given string in an array
  * @array: array of strings
  * @n: number of strings in the array or -1 for NULL terminated arrays
  * @str: string to match with
+ * @gaps: boolean to ignore NULL elements within the array
  *
  * Returns index of @str in the @array or -EINVAL, just like match_string().
  * Uses sysfs_streq instead of strcmp for matching.
+ * Ignores NULL pointers within the @array if @gaps is true.
  */
-int __sysfs_match_string(const char * const *array, size_t n, const char *str)
+int __sysfs_match_string_with_gaps(const char * const *array, size_t n,
+				   const char *str, bool gaps)
 {
 	const char *item;
 	int index;
 
 	for (index = 0; index < n; index++) {
 		item = array[index];
-		if (!item)
+		if (!item) {
+			if (gaps)
+				continue;
 			break;
+		}
 		if (sysfs_streq(item, str))
 			return index;
 	}
 
 	return -EINVAL;
 }
-EXPORT_SYMBOL(__sysfs_match_string);
+EXPORT_SYMBOL(__sysfs_match_string_with_gaps);
 
 #ifndef __HAVE_ARCH_MEMSET
 /**
@@ -659,30 +659,36 @@ int match_string(const char * const *array, size_t n, const char *string)
 
 /**
- * __sysfs_match_string - matches given string in an array
+ * __sysfs_match_string_with_gaps - matches string in array ignoring NULLs
  * @array: array of strings
  * @n: number of strings in the array or -1 for NULL terminated arrays
-- 
2.17.1




[Index of Archives]     [Linux USB Devel]     [Video for Linux]     [Linux Audio Users]     [Yosemite News]     [Linux Input]     [Linux Kernel]     [Linux SCSI]     [X.org]

  Powered by Linux